@@ -63,7 +63,7 @@
   #:use-module ((nyacc lex) #:select (cnumstr->scm))
   #:use-module ((nyacc util) #:select (ugly-print))
   #:re-export (*nyacc-version*)
-  #:version (2 02 4))
+  #:version (2 02 5))
 
 (define default-renamer (lambda (name ctxt) name))
 
@@ -580,7 +580,7 @@
       (`((array-of ,dim) . ,rest)
        `(make-list ,(eval-dim dim) ,(cnvt rest)))
       (`((array-of) . ,rest)
-       (cnvt `((array-of "0") . ,rest)))
+       (cnvt `((array-of (fixed "0")) . ,rest)))
 
       (`((struct-def (field-list . ,fields)))
        `(list ,@(map (lambda (fld)
@@ -608,6 +608,7 @@
 
   (match mtail
     (`((array-of ,dim) . ,rest) ''*)
+    (`((array-of) . ,rest) ''*)
     (__ (cnvt mtail))))
 
 (define* (defined-type-unwrapper name mname)
